require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.*"
import "android.text.*"
import "android.net.Uri"
import "android.speech.tts.TextToSpeech"

-- Global variable for TextToSpeech engine
local tts

function onCreate(savedInstanceState)
    local layout = LinearLayout(activity)
    activity.setTitle("Social Media links generator")
    layout.setOrientation(LinearLayout.VERTICAL)
    -- Heading
    headingTextView = TextView(activity)
    headingTextView.setText("Create Links")
    layout.addView(headingTextView)
    -- Initialize TextToSpeech engine
    tts = TextToSpeech(activity, nil)

    -- Function to create and copy link
    local function createAndCopyLink(baseURL, username, platform)
        if username == "" then
            tts.speak("Keyboard is empty. Please enter " .. platform .. " username first!", TextToSpeech.QUEUE_FLUSH, nil, nil)
elseif not string.match(username, "^[%w._]+$") then
            tts.speak("This username is invalid. Please enter a valid " .. platform .. " username.", TextToSpeech.QUEUE_FLUSH, nil, nil)
        else
            local link = baseURL .. username
            copyToClipboard(link)
            tts.speak("Link copied to clipboard", TextToSpeech.QUEUE_FLUSH, nil, nil)
        end
    end

    -- Function to open profile
    local function openProfile(baseURL, username, platform)
        if username == "" then
            tts.speak("Please enter " .. platform .. " username", TextToSpeech.QUEUE_FLUSH, nil, nil)
        elseif not string.match(username, "^[%w._]+$") then
            tts.speak("This username is invalid. Please enter a valid " .. platform .. " username.", TextToSpeech.QUEUE_FLUSH, nil, nil)
        else
            local intent = Intent(Intent.ACTION_VIEW)
            intent.setData(Uri.parse(baseURL .. username))
            activity.startActivity(intent)
        end
    end

    -- Function to share link
    local function shareLink(baseURL, username, platform)
        if username == "" then
            tts.speak("Please enter " .. platform .. " username", TextToSpeech.QUEUE_FLUSH, nil, nil)
elseif not string.match(username, "^[%w._]+$") then
            tts.speak("This username is invalid. Please enter a valid " .. platform .. " username.", TextToSpeech.QUEUE_FLUSH, nil, nil)
        else
            local link = baseURL .. username
            local intent = Intent(Intent.ACTION_SEND)
            intent.setType("text/plain")
            intent.putExtra(Intent.EXTRA_TEXT, link)
            activity.startActivity(Intent.createChooser(intent, "Share via"))
        end
    end

    -- Function to copy text to clipboard
    function copyToClipboard(text)
        local clipboardManager = activity.getSystemService(Context.CLIPBOARD_SERVICE)
        local clipData = ClipData.newPlainText("label", text)
        clipboardManager.setPrimaryClip(clipData)
    end

    -- Telegram Section
    local telegramLabel = TextView(activity)
    telegramLabel.setText("Telegram:")
    layout.addView(telegramLabel)

    local telegramEditText = EditText(activity)
    telegramEditText.setHint("Enter Telegram Username. like sushilrathore1712")
    layout.addView(telegramEditText)

    local telegramOpenProfileButton = Button(activity)
    telegramOpenProfileButton.setText("Open Telegram Profile")
    telegramOpenProfileButton.setOnClickListener{
        onClick=function(view)
            openProfile("https://t.me/", telegramEditText.getText().toString(), "Telegram")
        end
    }
    layout.addView(telegramOpenProfileButton)

    local telegramShareLinkButton = Button(activity)
    telegramShareLinkButton.setText("Share Telegram Link")
    telegramShareLinkButton.setOnClickListener{
        onClick=function(view)
            shareLink("https://t.me/", telegramEditText.getText().toString(), "Telegram")
        end
    }
    layout.addView(telegramShareLinkButton)

    -- Add copy link button for Telegram
    local telegramCopyLinkButton = Button(activity)
    telegramCopyLinkButton.setText("Copy Telegram Link")
    telegramCopyLinkButton.setOnClickListener{
        onClick=function(view)
            createAndCopyLink("https://t.me/", telegramEditText.getText().toString(), "Telegram")
        end
    }
    layout.addView(telegramCopyLinkButton)

    -- Twitter Section
    local twitterLabel = TextView(activity)
    twitterLabel.setText("Twitter:")
    layout.addView(twitterLabel)

    local twitterEditText = EditText(activity)
    twitterEditText.setHint("Enter Twitter Username")
    layout.addView(twitterEditText)

    local twitterOpenProfileButton = Button(activity)
    twitterOpenProfileButton.setText("Open Twitter Profile")
    twitterOpenProfileButton.setOnClickListener{
        onClick=function(view)
            openProfile("https://twitter.com/", twitterEditText.getText().toString(), "Twitter")
        end
    }
    layout.addView(twitterOpenProfileButton)

    local twitterShareLinkButton = Button(activity)
    twitterShareLinkButton.setText("Share Twitter Link")
    twitterShareLinkButton.setOnClickListener{
        onClick=function(view)
            shareLink("https://twitter.com/", twitterEditText.getText().toString(), "Twitter")
        end
    }
    layout.addView(twitterShareLinkButton)

    -- Add copy link button for Twitter
    local twitterCopyLinkButton = Button(activity)
    twitterCopyLinkButton.setText("Copy Twitter Link")
    twitterCopyLinkButton.setOnClickListener{
        onClick=function(view)
            createAndCopyLink("https://twitter.com/", twitterEditText.getText().toString(), "Twitter")
        end
    }
    layout.addView(twitterCopyLinkButton)

    -- Instagram Section
    local instagramLabel = TextView(activity)
    instagramLabel.setText("Instagram:")
    layout.addView(instagramLabel)

    local instagramEditText = EditText(activity)
    instagramEditText.setHint("Enter Instagram Username. like sushil__rathore_18")
    layout.addView(instagramEditText)

    local instagramOpenProfileButton = Button(activity)
    instagramOpenProfileButton.setText("Open Instagram Profile")
    instagramOpenProfileButton.setOnClickListener{
        onClick=function(view)
            openProfile("https://www.instagram.com/", instagramEditText.getText().toString(), "Instagram")
        end
    }
    layout.addView(instagramOpenProfileButton)

    local instagramShareLinkButton = Button(activity)
    instagramShareLinkButton.setText("Share Instagram Link")
    instagramShareLinkButton.setOnClickListener{
        onClick=function(view)
            shareLink("https://www.instagram.com/", instagramEditText.getText().toString(), "Instagram")
        end
    }
    layout.addView(instagramShareLinkButton)

    -- Add copy link button for Instagram
    local instagramCopyLinkButton = Button(activity)
    instagramCopyLinkButton.setText("Copy Instagram Link")
    instagramCopyLinkButton.setOnClickListener{
        onClick=function(view)
            createAndCopyLink("https://www.instagram.com/", instagramEditText.getText().toString(), "Instagram")
        end
    }
    layout.addView(instagramCopyLinkButton)

    -- TikTok Section
    local tikTokLabel = TextView(activity)
    tikTokLabel.setText("TikTok:")
    layout.addView(tikTokLabel)

    local tikTokEditText = EditText(activity)
    tikTokEditText.setHint("Enter TikTok Username")
    layout.addView(tikTokEditText)

    local tikTokOpenProfileButton = Button(activity)
    tikTokOpenProfileButton.setText("Open TikTok Profile")
    tikTokOpenProfileButton.setOnClickListener{
        onClick=function(view)
            openProfile("https://www.tiktok.com/@", tikTokEditText.getText().toString(), "TikTok")
        end
    }
    layout.addView(tikTokOpenProfileButton)

    local tikTokShareLinkButton = Button(activity)
    tikTokShareLinkButton.setText("Share TikTok Link")
    tikTokShareLinkButton.setOnClickListener{
        onClick=function(view)
            shareLink("https://www.tiktok.com/@", tikTokEditText.getText().toString(), "TikTok")
        end
    }
    layout.addView(tikTokShareLinkButton)

    -- Add copy link button for TikTok
    local tikTokCopyLinkButton = Button(activity)
    tikTokCopyLinkButton.setText("Copy TikTok Link")
    tikTokCopyLinkButton.setOnClickListener{
        onClick=function(view)
            createAndCopyLink("https://www.tiktok.com/@", tikTokEditText.getText().toString(), "TikTok")
        end
    }
    layout.addView(tikTokCopyLinkButton)

    -- About Button
    local aboutButton = Button(activity)
    aboutButton.setText("About")
    aboutButton.setOnClickListener{
        onClick=function(view)
            local aboutText = "This is a social media links generator tool. created by sushil rathore. About Social Media Links Generator:    The Social Media Links Generator tool is your ultimate tool for effortlessly managing your social media presence. Seamlessly generate, share, and copy links to your profiles on popular social media platforms with just a few taps.    Multi-Platform Support: Enjoy support for a variety of social media platforms including Telegram, Twitter, Instagram, and TikTok.    User-Friendly Interface: With a clean and intuitive interface, users can easily input their usernames and access various options to interact with their social media profiles."
            tts.speak(aboutText, TextToSpeech.QUEUE_FLUSH, nil, nil)
        end
    }
    layout.addView(aboutButton)

    -- Instructions Button
    local instructionsButton = Button(activity)
    instructionsButton.setText("Instructions")
    instructionsButton.setOnClickListener{
        onClick=function(view)
            local instructionsText = "Instructions: To use this tool, simply enter your username for the desired social media platform and then choose the action you want to perform. Social Media Links Generator Instructions: • Enter Username: Input your username for the desired social media platform. • Open Profile: Tap to view your profile. • Share Link: Tap to share your profile link. • Copy Link: Tap to copy your profile link.  You can use these characters to enter the username of the desired profile.  Available Platforms and Usable Keywords: • Telegram: Use 'Telegram' (A-Z, 0-9, _) in usernames. • Twitter: Use 'Twitter' (A-Z, 0-9, _) in usernames. • Instagram: Use 'Instagram' (A-Z, 0-9, _) in usernames. • TikTok: Use 'TikTok' (A-Z, 0-9, _) in usernames."
            tts.speak(instructionsText, TextToSpeech.QUEUE_FLUSH, nil, nil)
        end
    }
    layout.addView(instructionsButton)

    local scrollView = ScrollView(activity)
    scrollView.addView(layout)
    activity.setContentView(scrollView)
end

-- Function to destroy TextToSpeech engine when activity is destroyed
function onDestroy()
    if tts ~= nil then
        tts.shutdown()
    end
end

onCreate(nil)